@@ -51,7 +51,7 @@ import Data.Semigroup
 import Data.Semigroup.Reducer
 -- import Data.Sequence as Seq hiding (empty)
 import Data.Set as Set hiding (empty, toList)
-import Data.Text.Prettyprint.Doc as Pretty hiding (line)
+import Prettyprinter as Pretty hiding (line)
 import System.IO
 import Text.Parser.Combinators
 import Text.Parser.Char
